@@ -1,6 +1,6 @@
 # -*- coding: utf-8  -*-
 #
-# Copyright (C) 2012-2017 Ben Kurtovic <ben.kurtovic@gmail.com>
+# Copyright (C) 2012-2019 Ben Kurtovic <ben.kurtovic@gmail.com>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -38,7 +38,7 @@ class Template(Node):
 
     def __init__(self, name, params=None):
         super(Template, self).__init__()
-        self._name = name
+        self.name = name
         if params:
             self._params = params
         else:
@@ -108,7 +108,7 @@ class Template(Node):
     def _blank_param_value(value):
         """Remove the content from *value* while keeping its whitespace.
 
-        Replace *value*\ 's nodes with two text nodes, the first containing
+        Replace *value*\\ 's nodes with two text nodes, the first containing
         whitespace from before its content and the second containing whitespace
         from after its content.
         """
