@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2012-2015 Ben Kurtovic <ben.kurtovic@gmail.com>
+Copyright (C) 2012-2016 Ben Kurtovic <ben.kurtovic@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy of
 this software and associated documentation files (the "Software"), to deal in
@@ -24,7 +24,7 @@ SOFTWARE.
 
 #include "common.h"
 
-static const char MARKERS[] = {
+static const Unicode MARKERS[] = {
     '{', '}', '[', ']', '<', '>', '|', '=', '&', '\'', '#', '*', ';', ':', '/',
     '-', '!', '\n', '\0'};
 
